@@ -1,5 +1,5 @@
 package Smart::Comments;
-$Smart::Comments::VERSION = '1.05_01'; # TRIAL
+$Smart::Comments::VERSION = '1.05_02'; # TRIAL
 use 5.008;
 use warnings;
 use strict;
@@ -1061,7 +1061,7 @@ L<http://rt.cpan.org>.
 
 =head1 REPOSITORY
 
-L<https://github.com/neilbowers/Smart-Comments>
+L<https://github.com/neilb/Smart-Comments>
 
 
 =head1 AUTHOR
